@@ -93,7 +93,15 @@ importlib_resources_backport_read_binary_spec = BuiltinParameterSpec(
     default_count=0,
     type_shape=tshape_bytes,
 )
-importlib_resources_read_text_spec = BuiltinParameterSpec(
+importlib_resources_read_text_since_313_spec = BuiltinParameterSpec(
+    "importlib.resources.read_text",
+    ("package",),
+    list_star_arg="resources",
+    kw_only_args=("encoding", "errors"),
+    default_count=2,
+    type_shape=tshape_str,
+)
+importlib_resources_read_text_before_313_spec = BuiltinParameterSpec(
     "importlib.resources.read_text",
     ("package", "resource", "encoding", "errors"),
     default_count=2,
@@ -143,6 +151,13 @@ os_path_isabs_spec = BuiltinParameterSpec(
 
 os_listdir_spec = BuiltinParameterSpec("os.listdir", ("path",), default_count=1)
 
+os_stat_spec = BuiltinParameterSpec(
+    "os.stat", ("path",), kw_only_args=("dir_fd", "follow_symlinks"), default_count=2
+)
+os_lstat_spec = BuiltinParameterSpec(
+    "os.lstat", ("path",), kw_only_args=("dir_fd",), default_count=1
+)
+
 ctypes_cdll_since_38_spec = BuiltinParameterSpec(
     "ctypes.CDLL",
     (
